@@ -75,10 +75,12 @@ class EManafa(Service):
     def stop(self):
         b_out = self.batterystats.stop()
         p_out = self.perfetto.stop()
+        log("Perfetto file:  %s" % p_out)
         self.parseResults(b_out, p_out)
 
         if len(self.bat_events.events) > 0:
             hunter_out = self.hunter.start()  # hunter start is to write to a log file (same as stop)
+            #hunter_out = '/usr/local/Cellar/python@3.9/3.9.0_4/Frameworks/Python.framework/Versions/3.9/lib/python3.9/site-packages/manafa/results/hunter//hunter-1614351254.0.log'
             self.hunter.parseFile(hunter_out)
             hunter_trace = self.hunter.trace
 
@@ -291,7 +293,7 @@ if __name__ == '__main__':
     if has_device_conn and invalid_file_args:
         g.init()
         g.start()
-        time.sleep(7)  # do work
+        time.sleep(5)  # do work
         args.batstatsfile, args.perfettofile, hunter_file = g.stop()
     g.parseResults(args.batstatsfile, args.perfettofile)
     begin = g.bat_events.events[0].time  # first collected sample from batterystats
