@@ -2,7 +2,7 @@ import sysconfig
 from subprocess import Popen, PIPE
 from textops import find
 
-DEV=True
+DEV=False
 
 
 def get_resources_dir(packname="manafa", default_res_dir="resources"):
